api/track/info.json
Пред. | Глава 6. Web API | След.

## api/track/info.json

Возвращает информацию о композиции идентификатор которой указан в параметре `id`. Пример:

    $ curl 'http://music.tmradio.net/track/info.json?id=6065'
    {
     "real_weight": 1.0,
     "last_played": 1326743926,
     "weight": 1.1499999999999999,
     "image": "http://userserve-ak.last.fm/serve/64s/30245783.jpg",
     "labels": [ "calm", "female", "fresh", "music", "vocals", "source:jamendo.com" ],
     "download": null,
     "id": 6065,
     "count": 5,
     "filepath": "/radio/music/7/4/746fee45f4b312d28bba71b7cb2529fa.ogg",
     "artist": "KOOQLA",
     "title": "In my mind",
     "filename": "7/4/746fee45f4b312d28bba71b7cb2529fa.ogg",
     "length": 296
    }

Возможные свойства

id

  Уникальный числовой идентификатор композиции.

artist

  Название исполнителя.

title

  Название композиции.

weight

  Текущий вес композиции. Влияет на частоту проигрывания. Изменяется при обращении к api/track/rocks.json и api/track/sucks.json. Нулевой вес означает, что композиция была удалена из ротации.

real_weight

  Реальный вес композиции, рассчитанный автоматически. Текущий вес (`weight`) к нему по-немногу смещается при каждом проигрывании композиции.

count

  Количество проигрываний композиции.

length

  Продолжительность композиции в секундах.

last_played

  UNIX-время последнего проигрывания композиции.

labels

  Метки композиции. Используются для включения в плейлисты.

image

  URL иллюстрации к композиции. Обычно ведёт на сервер LastFM; картинка обычно имеет размер 64×64, но он может быть и другим (особенно если картинка с Jamendo).

download

  URL для скачивания композиции. Есть не всегда. Когда есть, не всегда является ссылкой на чистый MP3-файл, поэтому при сохранении лучше сформировать имя файла самостоятельно, на основе имени исполнителя и композиции.

last_played

  UNIX-время последнего проигрывания композиции.

filename

  Относительное имя файла в файловом хранилище.

filepath

  Абсолютное имя файла в файловом хранилище.

Пред. | Наверх | След.
api/track/sucks.json | Начало | Приложение A. Описание параметров командной строки